@@ -9,17 +9,31 @@ use App::Netdisco::Util::Device qw/get_device renumber_device/;
 
 register_worker({ phase => 'check' }, sub {
   my ($job, $workerconf) = @_;
+  my ($device, $port, $extra) = map {$job->$_} qw/device port extra/;
 
   return Status->error('Missing device (-d).')
-    unless defined shift->device;
+    unless defined $device;
 
-  my $new_ip = NetAddr::IP->new($job->extra);
-  unless ($new_ip and $new_ip->addr ne '0.0.0.0') {
-      return Status->error("Bad host or IP: ".($job->extra || '0.0.0.0'));
+  if (! $device->in_storage) {
+      return Status->error(sprintf "unknown device: %s.", $device);
   }
 
-  debug 'NB: this feature will change the primary IP of a device to support migrations';
-  debug 'NB: use the device_identity feature if you wish to steer Netdisco in choosing the canonical IP of devices';
+  my $new_ip = NetAddr::IP->new($extra);
+  unless ($new_ip and $new_ip->addr ne '0.0.0.0') {
+      return Status->error("bad host or IP: ".($extra || '0.0.0.0'));
+  }
+
+  debug sprintf 'renumber - from IP: %s', $device;
+  debug sprintf 'renumber -   to IP: %s (param: %s)', $new_ip->addr, $extra;
+
+  if ($new_ip->addr eq $device->ip) {
+      return Status->error('old and new are the same device (use device_identity instead).');
+  }
+
+  my $new_dev = get_device($new_ip->addr);
+  if ($new_dev and $new_dev->in_storage and ($new_ip->addr ne $device->ip)) {
+      return Status->error(sprintf "already know new device as: %s (use device_identity instead).", $new_dev->ip);
+  }
 
   return Status->done('Renumber is able to run');
 });
@@ -31,14 +45,9 @@ register_worker({ phase => 'main' }, sub {
   my $old_ip = $device->ip;
   my $new_ip = NetAddr::IP->new($extra);
 
-  my $new_dev = get_device($new_ip->addr);
-  if ($new_dev and $new_dev->in_storage and ($new_dev->ip ne $device->ip)) {
-      return Status->error(sprintf "Already know new device as: %s.", $new_dev->ip);
-  }
-
-  renumber_device($device, $new_ip);
+  renumber_device($old_ip, $new_ip);
   return Status->done(sprintf 'Renumbered device %s to %s (%s).',
-    $device->ip, $new_ip, ($device->dns || ''));
+    $old_ip, $new_ip, ($device->dns || ''));
 });
 
 true;
